"use server";

import { AuthConfig } from "@/auth";
import { requestGetFetch } from "@/utils/fetch";
import { Session } from "next-auth";
import { getServerSession } from "next-auth";

export async function getCoinRequestList(status: string) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "coin-request/list/" + status;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}

export async function getPendingWithDrawalsCoinRequests(status: string) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "coin-request/withDrawList/" + status;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}


export async function createCoinRequest(data: { coins: number }) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "coin-request/create";
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}


export async function editCoinTransfer(data: { approved_coins: string | number, status: string }, userId:string) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "coin-request/transfer/" + userId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}

export async function editCoinWithdraw(data: { withDraw_coins: string | number; status: string }, userId: string) {
  try {
    // TODO: not adding the right amount when user requesting coin withdraws, removing huge amount of coints from club, 
    // not reducing from user account
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "coin-request/withDraw-transfer/" + userId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}